@@ -137,7 +137,7 @@ void usage(void)
 void add_redir_to_file(char mode, char *file, redirect_t **predir, int *n_redirect)
 {
 	int cur_index = (*n_redirect)++;
-	*predir = (redirect_t *)myrealloc(*predir, (*n_redirect) * sizeof(redirect_t), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	*predir = (redirect_t *)myrealloc(*predir, (*n_redirect) * sizeof(redirect_t));
 
 	assert(mode == 'A' || mode == 'a');
 
@@ -146,11 +146,11 @@ void add_redir_to_file(char mode, char *file, redirect_t **predir, int *n_redire
 	else
 		(*predir)[cur_index].type = REDIRECTTO_FILE;
 
-	(*predir)[cur_index].redirect = mystrdup(file, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	(*predir)[cur_index].redirect = mystrdup(file);
 
 	(*predir)[cur_index].fd = open((*predir)[cur_index].redirect, O_WRONLY | O_CREAT | O_APPEND, S_IRUSR | S_IWUSR);
 	if ((*predir)[cur_index].fd == -1)
-		error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "%s: cannot open file %s for write access.\n", file, (*predir)[cur_index].redirect);
+		error_exit("%s: cannot open file %s for write access.\n", file, (*predir)[cur_index].redirect);
 }
 
 void add_redir_to_proc(char mode, char *proc, redirect_t **predir, int *n_redirect)
@@ -159,16 +159,16 @@ void add_redir_to_proc(char mode, char *proc, redirect_t **predir, int *n_redire
 
 	assert(mode == 'G' || mode == 'g');
 
-	*predir = (redirect_t *)myrealloc(*predir, (*n_redirect + 1) * sizeof(redirect_t), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	*predir = (redirect_t *)myrealloc(*predir, (*n_redirect + 1) * sizeof(redirect_t));
 
-	if ((*predir)[*n_redirect].type != REDIRECTTO_NONE) error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "One can only set one redirection-type per (sub-)window.\n");
+	if ((*predir)[*n_redirect].type != REDIRECTTO_NONE) error_exit("One can only set one redirection-type per (sub-)window.\n");
 
 	if (mode == 'g')
 		(*predir)[*n_redirect].type = REDIRECTTO_PIPE_FILTERED;
 	else
 		(*predir)[*n_redirect].type = REDIRECTTO_PIPE;
 
-	(*predir)[*n_redirect].redirect = mystrdup(proc, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	(*predir)[*n_redirect].redirect = mystrdup(proc);
 
 	(*predir)[*n_redirect].pid = exec_with_pipe((*predir)[*n_redirect].redirect, fds_to_proc, fds_from_proc);
 	myclose(fds_to_proc[0]);
@@ -182,13 +182,18 @@ void add_redir_to_proc(char mode, char *proc, redirect_t **predir, int *n_redire
 
 void add_redir_to_socket(char filtered, char *prio, char *fac, char *address, redirect_t **predir, int *n_redirect)
 {
-	struct hostent *hp;
-	char *local_address = mystrdup(address, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	char *local_address = mystrdup(address);
 	char *colon = strchr(local_address, ':');
 	int prio_nr = -1, fac_nr = -1;
 	int loop;
+    char* node;
+    char* service;
+    struct addrinfo hints;
+    struct addrinfo* result;
+    struct addrinfo* rp;
+    int s, sfd = -1;
 
-	*predir = (redirect_t *)myrealloc(*predir, (*n_redirect) * sizeof(redirect_t), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	*predir = (redirect_t *)myrealloc(*predir, (*n_redirect) * sizeof(redirect_t));
 
 	assert(filtered == 1 || filtered == 0);
 
@@ -197,23 +202,46 @@ void add_redir_to_socket(char filtered, char *prio, char *fac, char *address, re
 	else
 		(*predir)[*n_redirect].type = REDIRECTTO_SOCKET;
 
-	(*predir)[*n_redirect].redirect = mystrdup(address, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	(*predir)[*n_redirect].redirect = mystrdup(address);
 
-	(*predir)[*n_redirect].fd = socket(AF_INET, SOCK_DGRAM, 0);
-	if ((*predir)[*n_redirect].fd == -1)
-		error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Cannot create socket for redirecting via syslog protocol.\n");
-	
-	memset(&(*predir)[*n_redirect].sai, 0x00, sizeof((*predir)[*n_redirect].sai));
-	(*predir)[*n_redirect].sai.sin_family = AF_INET;
 	if (colon)
 	{
 		*colon = 0x00;
-		(*predir)[*n_redirect].sai.sin_port = atoi(colon + 1);
+		node = local_address;
+		service = colon + 1;
 	}
 	else
-		(*predir)[*n_redirect].sai.sin_port = 514;
-	hp = gethostbyname(local_address);
-	memcpy(&(*predir)[*n_redirect].sai.sin_addr.s_addr, hp -> h_addr, hp -> h_length);
+	{
+		node = local_address;
+		service = "syslog";
+	}
+
+	memset(&hints, 0x00, sizeof(struct addrinfo));
+	hints.ai_family = AF_UNSPEC;
+	hints.ai_socktype = SOCK_DGRAM;
+	hints.ai_flags = 0;
+	hints.ai_protocol = 0;
+
+	s = getaddrinfo(node, service, &hints, &result);
+	if (s != 0)
+		error_exit("Cannot create socket for redirecting via syslog protocol: %s.\n", gai_strerror(s));
+
+	for (rp = result; rp != NULL; rp = rp -> ai_next)
+	{
+		sfd = socket(rp -> ai_family, rp -> ai_socktype, rp -> ai_protocol);
+		if (sfd == -1)
+		    continue;
+		if (connect(sfd, rp -> ai_addr, rp -> ai_addrlen) != -1)
+		    break;
+		close(sfd);
+	}
+
+	freeaddrinfo(result);
+
+	if (rp == NULL)
+		error_exit("Cannot create socket for redirecting via syslog protocol.\n");
+
+	(*predir)[*n_redirect].fd = sfd;
 	
 	for(loop=0; loop<8; loop++)
 	{
@@ -224,7 +252,7 @@ void add_redir_to_socket(char filtered, char *prio, char *fac, char *address, re
 		}
 	}
 	if (prio_nr == -1)
-		error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Priority '%s' is not recognized.\n", prio);
+		error_exit("Priority '%s' is not recognized.\n", prio);
 	
 	for(loop=0; loop<24; loop++)
 	{
@@ -235,7 +263,7 @@ void add_redir_to_socket(char filtered, char *prio, char *fac, char *address, re
 		}
 	}
 	if (fac_nr == -1)
-		error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Facility '%s' is not known.\n", fac);
+		error_exit("Facility '%s' is not known.\n", fac);
 
 	(*predir)[*n_redirect].prio_fac = (fac_nr * 8) + prio_nr;
 
@@ -247,7 +275,7 @@ void add_redir_to_socket(char filtered, char *prio, char *fac, char *address, re
 void argv_set_window_widths(char *widths)
 {
 	if (split != 0)
-		error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "-s and -sw are mutual exclusive.\n");
+		error_exit("-s and -sw are mutual exclusive.\n");
 
 	split = 0;
 	for(;;)
@@ -259,7 +287,7 @@ void argv_set_window_widths(char *widths)
 		if (!pnt) break;
 
 		split++;
-		vertical_split = (int *)myrealloc(vertical_split, split * sizeof(int), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+		vertical_split = (int *)myrealloc(vertical_split, split * sizeof(int));
 
 		cur_width = get_value_arg("-sw", pnt, VAL_POSITIVE);
 		widths = NULL;
@@ -269,14 +297,14 @@ void argv_set_window_widths(char *widths)
 			if (cur_width == 0)
 				cur_width = -1;
 			else
-				error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "The width of a column must be 4 or greater (or '0' for automatic size).\n");
+				error_exit("The width of a column must be 4 or greater (or '0' for automatic size).\n");
 		}
 
 		vertical_split[split - 1] = cur_width;
 	}
 
 	if (split == 1)
-		error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "You have to give the width for each window or set it to 0 (=auto width).\n");
+		error_exit("You have to give the width for each window or set it to 0 (=auto width).\n");
 }
 
 void argv_set_n_windows_per_column(char *pars)
@@ -284,7 +312,7 @@ void argv_set_n_windows_per_column(char *pars)
 	int index = 0;
 
 	if (split == 0)
-		error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "First use -s or -sw to define the number of columns.\n");
+		error_exit("First use -s or -sw to define the number of columns.\n");
 
 	for(;;)
 	{
@@ -295,13 +323,13 @@ void argv_set_n_windows_per_column(char *pars)
 		if (!pnt) break;
 
 		index++;
-		n_win_per_col = (int *)myrealloc(n_win_per_col, index * sizeof(int), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+		n_win_per_col = (int *)myrealloc(n_win_per_col, index * sizeof(int));
 
 		cur_n = get_value_arg("-sn", pnt, VAL_POSITIVE);
 		pars = NULL;
 
 		if (cur_n < 0)
-			error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "The number of windows must be either 0 (=auto) or >= 1.\n");
+			error_exit("The number of windows must be either 0 (=auto) or >= 1.\n");
 
 		n_win_per_col[index - 1] = cur_n;
 	}
@@ -334,7 +362,7 @@ int argv_add_re(char *mode, char *pars[], char invert_regex, re **pre_cur, int *
 	else if (toupper(mode[2]) == 'X')
 		regex_mode = mode[2];	/* x = execute */
 	else
-		error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "%s is an unknown switch.\n", mode);
+		error_exit("%s is an unknown switch.\n", mode);
 
 	/* get expression */
 	expr = pars[n_pars_used++];
@@ -345,12 +373,12 @@ int argv_add_re(char *mode, char *pars[], char invert_regex, re **pre_cur, int *
 		cmd = pars[n_pars_used++];
 
 		if (regex_mode == 'X' && (strchr(expr, '(') == NULL || strchr(expr, ')') == NULL))
-			error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Filterscheme rule: -eX requires a regular expression which selects a substring using '(' and ')'.\n");
+			error_exit("Filterscheme rule: -eX requires a regular expression which selects a substring using '(' and ')'.\n");
 	}
 
 	/* compile & set expression */
 	/* allocate new structure */
-	*pre = (re *)myrealloc(*pre, sizeof(re) * (*n_re + 1), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	*pre = (re *)myrealloc(*pre, sizeof(re) * (*n_re + 1));
 
 	/* initialize structure */
 	memset(&(*pre)[*n_re], 0x00, sizeof(re));
@@ -359,7 +387,7 @@ int argv_add_re(char *mode, char *pars[], char invert_regex, re **pre_cur, int *
 	compile_re(&(*pre)[*n_re].regex, expr);
 
 	/* remember string for later edit */
-	(*pre)[*n_re].regex_str = mystrdup(expr, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	(*pre)[*n_re].regex_str = mystrdup(expr);
 
 	/* set flag on current file */
 	(*pre)[*n_re].use_regex = regex_mode;
@@ -369,13 +397,13 @@ int argv_add_re(char *mode, char *pars[], char invert_regex, re **pre_cur, int *
 	/* wether to invert the reg exp or not */
 	if ((regex_mode == 'v' || regex_mode == 'm') && invert_regex)
 	{
-		error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "-e[m] / -ev cannot be used together with -v\n");
+		error_exit("-e[m] / -ev cannot be used together with -v\n");
 	}
 	(*pre)[*n_re].invert_regex = invert_regex;
 
 	/* what to execute (if...) */
 	if (cmd)
-		(*pre)[*n_re].cmd = mystrdup(cmd, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+		(*pre)[*n_re].cmd = mystrdup(cmd);
 	else
 		(*pre)[*n_re].cmd = NULL;
 
@@ -409,7 +437,7 @@ int argv_color_settings(char *mode, char *pars[], char *allcolor, char *curcolor
 		if (pars[n_pars_used] != NULL && (strcasecmp(pars[n_pars_used], "ANSI") == 0 || strcasecmp(pars[n_pars_used], "vt100") == 0))
 			*cur_term_emul = TERM_ANSI;
 		else
-			error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Terminal emulation '%s' is not known.\n", pars[n_pars_used]);
+			error_exit("Terminal emulation '%s' is not known.\n", pars[n_pars_used]);
 
 		n_pars_used++;
 	}
@@ -418,14 +446,14 @@ int argv_color_settings(char *mode, char *pars[], char *allcolor, char *curcolor
 		int cur_scheme_index;
 		char *cur_cscheme = pars[n_pars_used++];
 		if (!cur_cscheme)
-			error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "%s requires a color scheme name.\n", mode);
+			error_exit("%s requires a color scheme name.\n", mode);
 
 		if ((cur_scheme_index = find_colorscheme(cur_cscheme)) == -1)
 		{
 			if (use_colors)
-				error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Color scheme %s not found! Please check your configuration file.\n", cur_cscheme);
+				error_exit("Color scheme %s not found! Please check your configuration file.\n", cur_cscheme);
 			else
-				error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Color schemes are not supported on monochrome terminals.\n");
+				error_exit("Color schemes are not supported on monochrome terminals.\n");
 		}
 
 		add_color_scheme(cur_color_schemes, cur_scheme_index);
@@ -445,7 +473,7 @@ int argv_color_settings(char *mode, char *pars[], char *allcolor, char *curcolor
 	}
 	else
 	{
-		error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Invalid -c mode: '%c'.\n", cur_mode);
+		error_exit("Invalid -c mode: '%c'.\n", cur_mode);
 	}
 
 	if (doall)
@@ -470,32 +498,32 @@ int argv_add_stripper(char *mode, char *pars[], strip_t **pstrip, int *n_strip)
 	{
 		char *re = pars[n_pars_used++];
 
-		*pstrip = myrealloc(*pstrip, (*n_strip + 1) * sizeof(strip_t), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+		*pstrip = myrealloc(*pstrip, (*n_strip + 1) * sizeof(strip_t));
 		if (mode[2] == 'e')
 			(*pstrip)[*n_strip].type = STRIP_TYPE_REGEXP;
 		else if (mode[2] == 'S')
 			(*pstrip)[*n_strip].type = STRIP_KEEP_SUBSTR;
-		(*pstrip)[*n_strip].regex_str = mystrdup(re, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+		(*pstrip)[*n_strip].regex_str = mystrdup(re);
 		(*pstrip)[*n_strip].del = NULL;
 		compile_re(&(*pstrip)[*n_strip].regex, re);
 		(*n_strip)++;
 	}
 	else if (mode[2] == 'r')
 	{
-		*pstrip = myrealloc(*pstrip, (*n_strip + 1) * sizeof(strip_t), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+		*pstrip = myrealloc(*pstrip, (*n_strip + 1) * sizeof(strip_t));
 		(*pstrip)[*n_strip].type = STRIP_TYPE_RANGE;
 		(*pstrip)[*n_strip].start = get_value_arg(mode, pars[n_pars_used++], VAL_ZERO_POSITIVE);
 		(*pstrip)[*n_strip].end = get_value_arg(mode, pars[n_pars_used++], VAL_ZERO_POSITIVE);
 		(*pstrip)[*n_strip].del = NULL;
 		if ((*pstrip)[*n_strip].end <= (*pstrip)[*n_strip].start)
-			error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "'-kr start end': end must be higher then start.\n");
+			error_exit("'-kr start end': end must be higher then start.\n");
 		(*n_strip)++;
 	}
 	else if (mode[2] == 'c')
 	{
-		*pstrip = myrealloc(*pstrip, (*n_strip + 1) * sizeof(strip_t), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+		*pstrip = myrealloc(*pstrip, (*n_strip + 1) * sizeof(strip_t));
 		(*pstrip)[*n_strip].type = STRIP_TYPE_COLUMN;
-		(*pstrip)[*n_strip].del = mystrdup(pars[n_pars_used++], __FILE__, __PRETTY_FUNCTION__, __LINE__);
+		(*pstrip)[*n_strip].del = mystrdup(pars[n_pars_used++]);
 		(*pstrip)[*n_strip].col_nr = get_value_arg(mode, pars[n_pars_used++], VAL_ZERO_POSITIVE);
 		(*n_strip)++;
 	}
@@ -504,20 +532,20 @@ int argv_add_stripper(char *mode, char *pars[], strip_t **pstrip, int *n_strip)
 		char *scheme = pars[n_pars_used++];
 		int editscheme_index = find_editscheme(scheme);
 		if (editscheme_index == -1)
-			error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "-ks %s: scheme not found.\n", scheme);
+			error_exit("-ks %s: scheme not found.\n", scheme);
 		duplicate_es_array(pes[editscheme_index].strips, pes[editscheme_index].n_strips, pstrip, n_strip);
 	}
 	else
-		error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "'%s' is not recognized.\n", mode);
+		error_exit("'%s' is not recognized.\n", mode);
 
 	return n_pars_used;
 }
 
 void add_glob_check(char *check_glob, int check_interval, char merge, char new_only)
 {
-	cdg = (check_dir_glob *)myrealloc(cdg, sizeof(check_dir_glob) * (n_cdg + 1), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	cdg = (check_dir_glob *)myrealloc(cdg, sizeof(check_dir_glob) * (n_cdg + 1));
 
-	cdg[n_cdg].glob_str       = mystrdup(check_glob, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	cdg[n_cdg].glob_str       = mystrdup(check_glob);
 	cdg[n_cdg].check_interval = check_interval;
 	cdg[n_cdg].in_one_window  = merge;
 	cdg[n_cdg].new_only       = new_only;
@@ -550,7 +578,7 @@ void do_commandline(int argc, char *argv[])
 	int_array_t cur_color_schemes = { NULL, 0, 0 };
 	myattr_t cdef = { -1, -1 };
 	int window_height = -1;
-	int initial_n_lines_tail = -1;
+	int initial_n_lines_tail = min_n_bufferlines;
 	char *win_title = NULL;
 	term_t cur_term_emul = TERM_IGNORE;
 	strip_t *pstrip = NULL;
@@ -618,10 +646,10 @@ void do_commandline(int argc, char *argv[])
 				if (what[0] == 'a' || what[0] == 'f')
 					bufferwhat = what[0];
 				else
-					error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "-bw expects either 'a' or 'f' as parameter (got: '%c').\n", what[0]);
+					error_exit("-bw expects either 'a' or 'f' as parameter (got: '%c').\n", what[0]);
 			}
 			else
-				error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "-bw expects a parameter ('a' or 'f').\n");
+				error_exit("-bw expects a parameter ('a' or 'f').\n");
 		}
 		else if (strcmp(argv[loop], "--no-repeat") == 0)
 		{
@@ -667,10 +695,10 @@ void do_commandline(int argc, char *argv[])
 			if (argv[loop])
 			{
 				heartbeat_interval = atof(argv[loop]);
-				if (heartbeat_interval < 0.0) error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "The value for -H must be >= 0.\n");
+				if (heartbeat_interval < 0.0) error_exit("The value for -H must be >= 0.\n");
 			}
 			else
-				error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "-H requires a parameter.\n");
+				error_exit("-H requires a parameter.\n");
 		}
 		else if (strcasecmp(argv[loop], "-a") == 0)
 		{
@@ -691,7 +719,7 @@ void do_commandline(int argc, char *argv[])
 
 			// -U[af][as] <facil> <prio> host[:port]
 			if (argv[loop][2] != 'a' && argv[loop][2] != 'f')
-				error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "-Ux where x needs to be either 'a' or 'f'");
+				error_exit("-Ux where x needs to be either 'a' or 'f'");
 
 			filtered = argv[loop][2] == 'f';
 			prio = argv[++loop];
@@ -704,7 +732,7 @@ void do_commandline(int argc, char *argv[])
 		{
 			config_file = argv[++loop];
 			if (file_exist(config_file) == -1)
-				error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Configuration file %s does not exist.\n", config_file);
+				error_exit("Configuration file %s does not exist.\n", config_file);
 
 			(void)do_load_config(-1, NULL, config_file);
 		}
@@ -724,15 +752,15 @@ void do_commandline(int argc, char *argv[])
 		{
 			++loop;
 			if (!argv[loop])
-				error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "-t requires a parameter.\n");
-			win_title = mystrdup(argv[loop], __FILE__, __PRETTY_FUNCTION__, __LINE__);
+				error_exit("-t requires a parameter.\n");
+			win_title = mystrdup(argv[loop]);
 		}
 		else if (strcmp(argv[loop], "-x") == 0)
 		{
 			++loop;
 			if (!argv[loop])
-				error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "-x requires a parameter.\n");
-			set_title = mystrdup(argv[loop], __FILE__, __PRETTY_FUNCTION__, __LINE__);
+				error_exit("-x requires a parameter.\n");
+			set_title = mystrdup(argv[loop]);
 		}
 		else if (argv[loop][0] == '-' && toupper(argv[loop][1]) == 'P')
 		{
@@ -747,10 +775,10 @@ void do_commandline(int argc, char *argv[])
 				if (cur_line_wrap == 'o')
 					cur_line_wrap_offset = get_value_arg("-p", argv[++loop], VAL_ZERO_POSITIVE);
 				else if (cur_line_wrap != 'a' && cur_line_wrap != 'l' && cur_line_wrap != 'r' && toupper(cur_line_wrap) != 'S' && cur_line_wrap != 'w')
-					error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Invalid mode for -p\n");
+					error_exit("Invalid mode for -p\n");
 			}
 			else
-				error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "-p requires a parameter.\n");
+				error_exit("-p requires a parameter.\n");
 		}
 		else if (strcmp(argv[loop], "--retry") == 0)
 		{
@@ -765,6 +793,10 @@ void do_commandline(int argc, char *argv[])
 		{
 			initial_n_lines_tail = get_value_arg("-n", argv[++loop], VAL_ZERO_POSITIVE);
 		}
+		else if (strcmp(argv[loop], "-N") == 0)
+		{
+			initial_n_lines_tail = min_n_bufferlines = get_value_arg("-n", argv[++loop], VAL_ZERO_POSITIVE);
+		}
 		else if (strcmp(argv[loop], "-b") == 0)
 		{
 			tab_width = get_value_arg("-b", argv[++loop], VAL_ZERO_POSITIVE);
@@ -811,7 +843,7 @@ void do_commandline(int argc, char *argv[])
 
 				filter = find_filterscheme(par);
 				if (filter == -1)
-					error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "'%s' is not a known filter scheme.\n", par);
+					error_exit("'%s' is not a known filter scheme.\n", par);
 
 				duplicate_re_array(pfs[filter].pre, pfs[filter].n_re, &pre, &n_re);
 
@@ -885,7 +917,7 @@ void do_commandline(int argc, char *argv[])
 		}
 		else if (strcasecmp(argv[loop], "--label") == 0)
 		{
-			label = mystrdup(argv[++loop], __FILE__, __PRETTY_FUNCTION__, __LINE__);
+			label = mystrdup(argv[++loop]);
 		}
 		else if (strcasecmp(argv[loop], "-i") == 0 || argv[loop][0] != '-' ||
 				strcasecmp(argv[loop], "-l") == 0 ||
@@ -909,7 +941,7 @@ void do_commandline(int argc, char *argv[])
 			}
 			else if (strcasecmp(argv[loop], "-j") == 0)
 			{
-				if (used_stdin == MY_TRUE) error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "One can use %s only once.\n", argv[loop]);
+				if (used_stdin == MY_TRUE) error_exit("One can use %s only once.\n", argv[loop]);
 				is_stdin = used_stdin = 1;
 			}
 			else if (strcasecmp(argv[loop], "-iw") == 0)
@@ -927,7 +959,7 @@ void do_commandline(int argc, char *argv[])
 					}
 				}
 				else
-					error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "-iw requires 2 parameters.\n");
+					error_exit("-iw requires 2 parameters.\n");
 			}
 			else if (strcasecmp(argv[loop], "--listen") == 0)
 			{
@@ -966,7 +998,7 @@ void do_commandline(int argc, char *argv[])
 					cur = cur -> next;
 				}
 
-				cur -> next = (proginfo *)mymalloc(sizeof(proginfo), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+				cur -> next = (proginfo *)mymalloc(sizeof(proginfo));
 
 				cur = cur -> next;
 
@@ -974,11 +1006,11 @@ void do_commandline(int argc, char *argv[])
 			}
 			else
 			{
-				pi = (proginfo *)myrealloc(pi, (nfd + 1) * sizeof(proginfo), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+				pi = (proginfo *)myrealloc(pi, (nfd + 1) * sizeof(proginfo));
 
-				lb = (buffer *)myrealloc(lb, (nfd + 1) * sizeof(buffer), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+				lb = (buffer *)myrealloc(lb, (nfd + 1) * sizeof(buffer));
 
-				nsubwindows = (char *)myrealloc(nsubwindows, (nfd + 1) * sizeof(char), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+				nsubwindows = (char *)myrealloc(nsubwindows, (nfd + 1) * sizeof(char));
 				nsubwindows[nfd] = 1;
 				memset(&lb[nfd], 0x00, sizeof(buffer));
 
@@ -1007,19 +1039,19 @@ void do_commandline(int argc, char *argv[])
 			/* see if file exists */
 			if (check_interval == 0 && is_cmd == 0 && is_stdin == 0 && is_sock == 0 && retry == 0 && stat64(dummy, &buf) == -1)
 			{
-				fprintf(stderr, "Error opening file %s.\n", dummy);
+				fprintf(stderr, "Error opening file %s (%s)\n", dummy, strerror(errno));
 				exit(EXIT_FAILURE);
 			}
 
 			/* init. struct. for this file */
 			if (is_stdin == 0)
 			{
-				if (!dummy) error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "No filename given.\n");
-				cur -> filename = mystrdup(dummy, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+				if (!dummy) error_exit("No filename given.\n");
+				cur -> filename = mystrdup(dummy);
 			}
 			else
 			{
-				cur -> filename = mystrdup("STDIN", __FILE__, __PRETTY_FUNCTION__, __LINE__);
+				cur -> filename = mystrdup("STDIN");
 			}
 			if (is_cmd)
 				cur -> wt = WT_COMMAND;
@@ -1039,7 +1071,7 @@ void do_commandline(int argc, char *argv[])
 
 			/* initial number of lines to tail */
 			cur -> initial_n_lines_tail = initial_n_lines_tail;
-			initial_n_lines_tail = -1;
+			initial_n_lines_tail = min_n_bufferlines;
 
 			/* default window height */
 			cur -> win_height = window_height;
@@ -1131,7 +1163,7 @@ void do_commandline(int argc, char *argv[])
 				}
 			}
 			cur -> cdef.field_nr = field_index;
-			cur -> cdef.field_del = field_delimiter ? mystrdup(field_delimiter, __FILE__, __PRETTY_FUNCTION__, __LINE__) : NULL;
+			cur -> cdef.field_del = field_delimiter ? mystrdup(field_delimiter) : NULL;
 
 			cur -> statistics.sccfirst = 1;
 
@@ -1186,10 +1218,10 @@ void do_commandline(int argc, char *argv[])
 				else if (strcasecmp(type, "ctime") == 0)
 					new_only = TT_CTIME;
 				else
-					error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "--new-only requires either atime, mtime or ctime as parameter, not '%s'.\n", type);
+					error_exit("--new-only requires either atime, mtime or ctime as parameter, not '%s'.\n", type);
 			}
 			else
-				error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "--new-only requires a parameter.\n");
+				error_exit("--new-only requires a parameter.\n");
 		}
 		else if (strcasecmp(argv[loop], "-q") == 0)
 		{
@@ -1212,7 +1244,7 @@ void do_commandline(int argc, char *argv[])
 			loop++;
 
 			if (!argv[loop])
-				error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "-o requires a parameter.\n");
+				error_exit("-o requires a parameter.\n");
 			else
 				config_file_entry(-1, argv[loop]);
 		}
