@@ -9,10 +9,16 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <ctype.h>
+#include <unistd.h>
+#include <errno.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
 
 #include "mt.h"
 #include "mem.h"
 #include "error.h"
+#include "utils.h"
+#include "exec.h"
 #include "globals.h"
 
 
@@ -38,17 +44,27 @@ char * epoch_to_str(time_t epoch)
 	if (!ptm)
 		return NULL;
 
-	new_string = mymalloc(4096, "epoch_to_str: new string");
+	new_string = mymalloc(4096);
 	if (!strftime(new_string, 4096, cnv_ts_format, ptm))
-		error_exit("epoch_to_str: error converting timestamp format '%s'\n", cnv_ts_format);
+		error_exit("An error occured whilte converting timestamp format '%s'.\n", cnv_ts_format);
 
 	return new_string;
 }
 
-char *do_convert(char *what, int type)
+char *do_convert(char *what, int what_len, int type, script *pscript)
 {
 	switch(type)
 	{
+		case CONVTYPE_SIGNRTOSTRING:
+			{
+				int signr = atoi(what);
+
+				if (signr > n_known_sigs || signr < 1)
+					return mystrdup("unknown signal");
+
+				return mystrdup(sigs[signr]);
+			}
+
 		case CONVTYPE_TAI64NTODATE:
 			{
 				long long int v2_62 = (long long int)1 << (long long int)62;
@@ -58,8 +74,7 @@ char *do_convert(char *what, int type)
 				if (what[0] == '@')
 					what++;
 
-				/* FIXME: http://cr.yp.to/libtai/tai64.html#tai64n */
-
+				/* http://cr.yp.to/libtai/tai64.html#tai64n */
 				/* convert to 64 bit integer */
 				for(loop=0; loop<(8 * 2); loop++)
 				{
@@ -72,36 +87,41 @@ char *do_convert(char *what, int type)
 						val += c - '0';
 				}
 
-				if (val >= v2_62) /* 2^63 are reserved, not checking for that, sorry */
+				if (val >= v2_62) /* FIXME: 2^63 are reserved, not checking for that, sorry */
 				{
 					char *new_str = epoch_to_str((time_t)(val - v2_62));
 
 					if (new_str)
 						return new_str;
 					else
-						return mystrdup("cannot convert current 'TAI64N'-date to string", "do_convert: invalid TAI64N timecode");
+						return mystrdup("cannot convert current 'TAI64N'-date to string");
 				}
 				else
 				{
 					/* before 1970/1/1 now what should I do with that? */
 
-					return mystrdup("cannot convert 'TAI64N'-dates before the epoch", "do_convert: TAI64N value to small");
+					return mystrdup("cannot convert 'TAI64N'-dates before the epoch");
 				}
 			}
 
 		case CONVTYPE_IP4TOHOST:
 			{
-				struct hostent *ht;
-				in_addr_t addr = inet_addr(what);
-				if ((int)addr == -1)
-					return mystrdup(what, "do_convert: unaltered string");
+				if (resolv_ip_addresses)
+				{
+					struct hostent *ht;
+					in_addr_t addr = inet_addr(what);
+					if ((int)addr == -1)
+						return mystrdup(what);
 
-				if ((ht = gethostbyaddr((char *)&addr, sizeof(addr), AF_INET)) == NULL)
-					return mystrdup(what, "do_convert: unaltered string");
+					if ((ht = gethostbyaddr((char *)&addr, sizeof(addr), AF_INET)) == NULL)
+						return mystrdup(what);
 
-				return mystrdup(ht -> h_name, "do_convert: looked-up hostname");
+					return mystrdup(ht -> h_name);
+				}
+
+				return mystrdup(what);
 			}
-			break; /* this redundant break-statement is what we call "defensive programming" */
+			break;
 
 		case CONVTYPE_EPOCHTODATE:
 			{
@@ -110,13 +130,13 @@ char *do_convert(char *what, int type)
 				if (new_str)
 					return new_str;
 				else
-					return mystrdup("cannot convert current epoch value", "do_convert: cannot convert epoch");
+					return mystrdup("cannot convert current epoch value");
 			}
 			break;
 
 		case CONVTYPE_ERRNO:
 			{
-				return mystrdup(strerror(atoi(what)), "do_convert: error string");
+				return mystrdup(strerror(atoi(what)));
 			}
 
 		case CONVTYPE_HEXTODEC:
@@ -126,7 +146,7 @@ char *do_convert(char *what, int type)
 
 				snprintf(result_str, sizeof(result_str), "%lld", result);
 
-				return mystrdup(result_str, "do_convert: decimal string");
+				return mystrdup(result_str);
 			}
 
 		case CONVTYPE_DECTOHEX:
@@ -136,17 +156,41 @@ char *do_convert(char *what, int type)
 
 				snprintf(result_str, sizeof(result_str), "%llx", result);
 
-				return mystrdup(result_str, "do_convert: hex string");
+				return mystrdup(result_str);
 			}
 
+		case CONVTYPE_SCRIPT:
+			{
+				int rc;
+				char *send_buffer = mymalloc(what_len + 1 + 1);
+				char *result_str = mymalloc(SCRIPT_IO_BUFFER_SIZE);
+
+				exec_script(pscript);
+
+				memcpy(send_buffer, what, what_len);
+				send_buffer[what_len] = '\n';
+				send_buffer[what_len + 1] = 0x00;
+
+				WRITE(pscript -> fd_w, send_buffer, what_len + 1, "conversion script (is it still running?)");
+				myfree(send_buffer);
+
+				rc = READ(pscript -> fd_r, result_str, SCRIPT_IO_BUFFER_SIZE - 1, pscript -> script);
+				result_str[rc > 0?rc - 1:rc] = 0x00;
+
+				return result_str;
+			}
+
+		case CONVTYPE_ABBRTOK:
+			return amount_to_str(atoll(what));
+
 		default:
-			error_exit("do_convert: internal error, unknown conversion type (%d)\n", type);
+			error_exit("Internal error: unknown conversion type %d.\n", type);
 	}
 
 	return "do_convert: INTERNAL ERROR";
 }
 
-char *convert(proginfo *cur, char *line)
+char *convert(int_array_t *pconversions, char *line)
 {
 	conversion *cur_conv = NULL;
 	cv_off *cv_offsets = NULL;
@@ -157,50 +201,64 @@ char *convert(proginfo *cur, char *line)
 	char *new_string = NULL;
 	int offset_old = 0, offset_new = 0;
 	int old_len = strlen(line);
+	int n_conversions = get_iat_size(pconversions);
 
-	if (cur -> n_conversions == 0)
+	if (n_conversions == 0)
 		return line;
 
-	for(conv_req=0; conv_req < cur -> n_conversions; conv_req++)
+	for(conv_req=0; conv_req < n_conversions; conv_req++)
 	{
-		cur_conv = &conversions[(cur -> conversions)[conv_req]];
+		cur_conv = &conversions[get_iat_element(pconversions, conv_req)];
 
 		max_n_cv_matches = cur_conv -> n * MAX_N_RE_MATCHES;
-		cv_offsets = (cv_off *)mymalloc(sizeof(cv_off) * max_n_cv_matches, "convert: array of offsets for conversions");
+		cv_offsets = (cv_off *)mymalloc(sizeof(cv_off) * max_n_cv_matches);
 
 		/* find where they match */
 		for(conv_index=0; conv_index<cur_conv -> n && cur_n_cv_matches < max_n_cv_matches; conv_index++)
 		{
-			regmatch_t matches[MAX_N_RE_MATCHES];
-
-			if (regexec(&(cur_conv -> regex)[conv_index], line, MAX_N_RE_MATCHES, matches, 0) == 0)
+			int offset = 0;
+			do
 			{
 				int cur_match_index;
-				LOG("convert match\n");
+				int cur_offset = offset;
+				regmatch_t matches[MAX_N_RE_MATCHES];
+
+				/* FIXME: what to do with regexp errors? */
+				if (regexec(&(cur_conv -> pcb)[conv_index].regex, &line[offset], MAX_N_RE_MATCHES, matches, offset?REG_NOTBOL:0) != 0)
+					break;
+
 				for(cur_match_index=1; cur_match_index<MAX_N_RE_MATCHES && cur_n_cv_matches < max_n_cv_matches; cur_match_index++)
 				{
 					char *dummy;
 					int dummylen;
+					int match_start, match_end;
+
+					match_start = matches[cur_match_index].rm_so + cur_offset;
+					match_end   = matches[cur_match_index].rm_eo + cur_offset;
+
+					offset = max(offset + 1, match_end);
 
 					if (matches[cur_match_index].rm_so == -1)
 						break;
 
-					(cur_conv -> match_count)[conv_index]++;
+					(cur_conv -> pcb)[conv_index].match_count++;
 
-					cv_offsets[cur_n_cv_matches].start = matches[cur_match_index].rm_so;
-					cv_offsets[cur_n_cv_matches].end   = matches[cur_match_index].rm_eo;
+					cv_offsets[cur_n_cv_matches].start = match_start;
+					cv_offsets[cur_n_cv_matches].end   = match_end;
 
-					dummylen = matches[cur_match_index].rm_eo - matches[cur_match_index].rm_so;
-					dummy = mymalloc(dummylen + 1, "convert: replace by");
-					memcpy(dummy, &line[matches[cur_match_index].rm_so], dummylen);
+					dummylen = match_end - match_start;
+
+					dummy = mymalloc(dummylen + 1);
+					memcpy(dummy, &line[match_start], dummylen);
 					dummy[dummylen] = 0x00;
-					cv_offsets[cur_n_cv_matches].newstr= do_convert(dummy, (cur_conv -> type)[conv_index]);
-					LOG("convert newstr: %s\n", cv_offsets[cur_n_cv_matches].newstr);
+
+					cv_offsets[cur_n_cv_matches].newstr = do_convert(dummy, dummylen, (cur_conv -> pcb)[conv_index].type, &(cur_conv -> pcs)[conv_index]);
+
 					myfree(dummy);
 
 					cur_n_cv_matches++;
 				}
-			}
+			} while (offset < old_len);
 		}
 	}
 
@@ -216,10 +274,9 @@ char *convert(proginfo *cur, char *line)
 		for(conv_index=0; conv_index < cur_n_cv_matches; conv_index++)
 		{
 			n_copy = cv_offsets[conv_index].start - offset_old;
-			LOG("convert replace by: %s\n", cv_offsets[conv_index].newstr);
 			if (n_copy > 0)
 			{
-				new_string = myrealloc(new_string, new_len + n_copy + 1, "convert: new_string");
+				new_string = myrealloc(new_string, new_len + n_copy + 1);
 				memcpy(&new_string[offset_new], &line[offset_old], n_copy);
 				new_string[offset_new + n_copy] = 0x00;
 				new_len += n_copy;
@@ -228,19 +285,18 @@ char *convert(proginfo *cur, char *line)
 			offset_old = cv_offsets[conv_index].end;
 
 			n_copy = strlen(cv_offsets[conv_index].newstr);
-			new_string = myrealloc(new_string, new_len + n_copy + 1, "convert: new_string");
+			new_string = myrealloc(new_string, new_len + n_copy + 1);
 			memcpy(&new_string[offset_new], cv_offsets[conv_index].newstr, n_copy);
 			new_string[offset_new + n_copy] = 0x00;
 			myfree(cv_offsets[conv_index].newstr);
 			new_len += n_copy;
 			offset_new += n_copy;
 		}
-		LOG("convert new string: %s\n", new_string);
 
 		n_copy = old_len - offset_old;
 		if (n_copy)
 		{
-			new_string = myrealloc(new_string, new_len + n_copy + 1, "convert: new_string");
+			new_string = myrealloc(new_string, new_len + n_copy + 1);
 			memcpy(&new_string[offset_new], &line[offset_old], n_copy);
 			new_string[offset_new + n_copy] = 0x00;
 		}
@@ -254,3 +310,25 @@ char *convert(proginfo *cur, char *line)
 
 	return new_string;
 }
+
+int find_conversion_scheme(char *name)
+{
+	int loop;
+
+	for(loop=0; loop<n_conversions; loop++)
+	{
+		if (strcmp(conversions[loop].name, name) == 0)
+			return loop;
+	}
+
+	return -1;
+}
+
+void add_conversion_scheme(int_array_t *conversions, char *conversion_name)
+{
+	int conversion_nr = find_conversion_scheme(conversion_name);
+	if (conversion_nr == -1)
+		error_exit("'%s' is not a known conversion scheme.\n", conversion_name);
+
+	add_to_iat(conversions, conversion_nr);
+}
