@@ -68,7 +68,7 @@ void LOG(char *s, ...)
 	if (!fh)
 	{
 		endwin();
-		error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "error logging\n");
+		error_exit("error logging\n");
 	}
 
 	va_start(ap, s);
@@ -82,7 +82,7 @@ void LOG(char *s, ...)
 typedef void (*sh_t)(int);
 void set_signal(int sig, sh_t func, char *signame)
 {
-	if (SIG_ERR == signal(sig, func)) error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Setting of handler for signal %s failed.\n", signame);
+	if (SIG_ERR == signal(sig, func)) error_exit("Setting of handler for signal %s failed.\n", signame);
 }
 
 void free_subentry(proginfo *entry)
@@ -229,8 +229,8 @@ char delete_entry(int f_index, proginfo *sub)
 		}
 		else		/* not empty, just shrink */
 		{
-			pi = (proginfo *)myrealloc(pi, nfd * sizeof(proginfo), __FILE__, __PRETTY_FUNCTION__, __LINE__);
-			lb = (buffer *)  myrealloc(lb, nfd * sizeof(buffer),   __FILE__, __PRETTY_FUNCTION__, __LINE__);
+			pi = (proginfo *)myrealloc(pi, nfd * sizeof(proginfo));
+			lb = (buffer *)  myrealloc(lb, nfd * sizeof(buffer));
 		}
 	}
 	else		/* delete sub */
@@ -385,7 +385,16 @@ void signal_handler(int sig)
 
 void select_display_start_and_end(char *string, char mode, int wrap_offset, int win_width, int *prt_start, int *prt_end, int *disp_end)
 {
-	int nbytes = strlen(string);
+	/* patch by Thomas Gartner */
+	int nbytes = 0; /* = strlen(string); */
+	char *tmpString=string;
+	while(string && *tmpString)
+	{
+		if (*tmpString++==9)
+			nbytes += tab_width;
+		else
+			++nbytes;
+	}
 
 	*prt_start = 0;
 	*prt_end = nbytes;
@@ -455,7 +464,7 @@ int draw_tab(NEWWIN *win)
 	return 0;
 }
 
-	
+
 char find_highlight_matches(regmatch_t *matches, char use_regex, int offset)
 {
 	int match_offset;
@@ -482,65 +491,65 @@ char find_highlight_matches(regmatch_t *matches, char use_regex, int offset)
 
 myattr_t * find_cmatches_index(color_offset_in_line *cmatches, int n_cmatches, mybool_t has_merge_colors, int offset)
 {
-        static myattr_t final_color;
-        int cmatches_index = 0;
-        int fg_composed = -1, bg_composed = -1;
-        int attrs = -1;
-        char first_set = 1;
+	static myattr_t final_color;
+	int cmatches_index = 0;
+	int fg_composed = -1, bg_composed = -1;
+	int attrs = -1;
+	char first_set = 1;
 
-        for(cmatches_index=0; cmatches_index<n_cmatches; cmatches_index++)
-        {
-                if (offset >= cmatches[cmatches_index].start && offset < cmatches[cmatches_index].end)
-                {
-                        if (has_merge_colors == MY_FALSE)
+	for(cmatches_index=0; cmatches_index<n_cmatches; cmatches_index++)
+	{
+		if (offset >= cmatches[cmatches_index].start && offset < cmatches[cmatches_index].end)
+		{
+			if (has_merge_colors == MY_FALSE)
 			{
-                                return &cmatches[cmatches_index].attrs;
+				return &cmatches[cmatches_index].attrs;
 			}
 
-                        if (cmatches[cmatches_index].merge_color == MY_TRUE)
-                        {
-                                /* merge these colors */
-                                if (cmatches[cmatches_index].attrs.colorpair_index != -1)
-                                {
-                                        int fg_fc, bg_fc;
+			if (cmatches[cmatches_index].merge_color == MY_TRUE)
+			{
+				/* merge these colors */
+				if (cmatches[cmatches_index].attrs.colorpair_index != -1)
+				{
+					int fg_fc, bg_fc;
 
-                                        fg_fc = cp.fg_color[cmatches[cmatches_index].attrs.colorpair_index];
-                                        bg_fc = cp.bg_color[cmatches[cmatches_index].attrs.colorpair_index];
+					fg_fc = cp.fg_color[cmatches[cmatches_index].attrs.colorpair_index];
+					bg_fc = cp.bg_color[cmatches[cmatches_index].attrs.colorpair_index];
 
-                                        if (fg_fc != -1 && fg_composed == -1)
-                                                fg_composed = fg_fc;
-                                        if (bg_fc != -1 && bg_composed == -1)
-                                                bg_composed = bg_fc;
-                                }
+					if (fg_fc != -1 && fg_composed == -1)
+						fg_composed = fg_fc;
+					if (bg_fc != -1 && bg_composed == -1)
+						bg_composed = bg_fc;
+				}
 
-                                if (cmatches[cmatches_index].attrs.attrs != -1)
-                                {
-                                        if (attrs == -1)
-                                                attrs = cmatches[cmatches_index].attrs.attrs;
-                                        else
-                                                attrs |= cmatches[cmatches_index].attrs.attrs;
-                                }
-                        }
-                        else if (first_set)
-                        {
-                                first_set = 0;
+				if (cmatches[cmatches_index].attrs.attrs != -1)
+				{
+					if (attrs == -1)
+						attrs = cmatches[cmatches_index].attrs.attrs;
+					else
+						attrs |= cmatches[cmatches_index].attrs.attrs;
+				}
+			}
+			else if (first_set)
+			{
+				first_set = 0;
 
-                                fg_composed = cp.fg_color[cmatches[cmatches_index].attrs.colorpair_index];
-                                bg_composed = cp.bg_color[cmatches[cmatches_index].attrs.colorpair_index];
-                                attrs = cmatches[cmatches_index].attrs.attrs;
-                        }
-                }
-        }
+				fg_composed = cp.fg_color[cmatches[cmatches_index].attrs.colorpair_index];
+				bg_composed = cp.bg_color[cmatches[cmatches_index].attrs.colorpair_index];
+				attrs = cmatches[cmatches_index].attrs.attrs;
+			}
+		}
+	}
 
-        if (fg_composed != -1 || bg_composed != -1 || final_color.attrs != -1)
-        {
-                final_color.attrs = attrs;
-                final_color.colorpair_index = find_or_init_colorpair(fg_composed, bg_composed, 1);
+	if (fg_composed != -1 || bg_composed != -1 || final_color.attrs != -1)
+	{
+		final_color.attrs = attrs;
+		final_color.colorpair_index = find_or_init_colorpair(fg_composed, bg_composed, 1);
 
-                return &final_color;
-        }
+		return &final_color;
+	}
 
-        return NULL;
+	return NULL;
 }
 
 void gen_wordwrap_offsets(char *string, int start_offset, int end_offset, int win_width, int **offsets)
@@ -564,7 +573,7 @@ void gen_wordwrap_offsets(char *string, int start_offset, int end_offset, int wi
 
 		if (max_len >= 0)
 		{
-			*offsets = (int *)myrealloc(*offsets, (n_ww + 1) * sizeof(int), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+			*offsets = (int *)myrealloc(*offsets, (n_ww + 1) * sizeof(int));
 			(*offsets)[n_ww++] = check_x;
 		}
 		else
@@ -573,7 +582,7 @@ void gen_wordwrap_offsets(char *string, int start_offset, int end_offset, int wi
 		}
 	}
 
-	*offsets = (int *)myrealloc(*offsets, (n_ww + 1) * sizeof(int), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	*offsets = (int *)myrealloc(*offsets, (n_ww + 1) * sizeof(int));
 	(*offsets)[n_ww] = -1;
 }
 
@@ -712,7 +721,7 @@ void color_print(int f_index, NEWWIN *win, proginfo *cur, char *string, regmatch
 {
 	char reverse = 0;
 	myattr_t cdev = { -1, -1 };
-	int prt_start = 0, prt_end, disp_end;
+	int prt_start = 0, prt_end = 0, disp_end = 0;
 	int mx = -1;
 	char use_regex = 0;
 	color_offset_in_line *cmatches = NULL;
@@ -836,7 +845,7 @@ void check_filter_exec(char *cmd, char *matching_string)
 	int str_index, par_len = strlen(matching_string);
 	int cmd_len = strlen(cmd);
 	char *command = mymalloc(cmd_len + 1/* cmd + space */
-			+ 1 + (par_len * 2) + 1 + 1, __FILE__, __PRETTY_FUNCTION__, __LINE__); /* "string"\0 */
+			+ 1 + (par_len * 2) + 1 + 1); /* "string"\0 */
 	int loop;
 
 	memcpy(command, cmd, cmd_len);
@@ -863,7 +872,7 @@ void check_filter_exec(char *cmd, char *matching_string)
 
 /* check if the current line matches with a regular expression
    returns 0 if a regexp failed to execute
-   */
+ */
 
 /* this code can be optimized quit a bit but I wanted to get it to work quickly so I expanded everything (2006/03/28) */
 char check_filter(proginfo *cur, char *string, regmatch_t **pmatch, char **error, int *matching_regex, char do_re, char *display)
@@ -874,7 +883,8 @@ char check_filter(proginfo *cur, char *string, regmatch_t **pmatch, char **error
 	char re_exec_ok = 1;
 
 	*error = NULL;
-	*pmatch = NULL;
+	if (pmatch)
+		*pmatch = NULL;
 	*matching_regex = -1;
 
 	*display = 1;
@@ -896,7 +906,7 @@ char check_filter(proginfo *cur, char *string, regmatch_t **pmatch, char **error
 		if (pmatch)
 		{
 			if (*pmatch == NULL)
-				*pmatch = (regmatch_t *)mymalloc(sizeof(regmatch_t) * MAX_N_RE_MATCHES, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+				*pmatch = (regmatch_t *)mymalloc(sizeof(regmatch_t) * MAX_N_RE_MATCHES);
 
 			rc = regexec(&(cur -> pre)[loop].regex, string, MAX_N_RE_MATCHES, *pmatch, 0);
 		}
@@ -941,7 +951,7 @@ char check_filter(proginfo *cur, char *string, regmatch_t **pmatch, char **error
 				{
 					regmatch_t *usep = USE_IF_SET(*pmatch, local_matches);
 					int len = usep[1].rm_eo - usep[1].rm_so;
-					char *dummy = (char *)mymalloc(len + 1, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+					char *dummy = (char *)mymalloc(len + 1);
 					memcpy(dummy, &string[usep[1].rm_so], len);
 					dummy[len] = 0x00;
 					check_filter_exec((cur -> pre)[loop].cmd, dummy);
@@ -991,7 +1001,7 @@ char check_filter(proginfo *cur, char *string, regmatch_t **pmatch, char **error
 				else if (cmd == 'X' && do_re)
 				{
 					int len = *pmatch ? (*pmatch)[1].rm_eo - (*pmatch)[1].rm_so : local_matches[1].rm_eo - local_matches[1].rm_so;
-					char *dummy = (char *)mymalloc(len + 1, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+					char *dummy = (char *)mymalloc(len + 1);
 					memcpy(dummy, &string[local_matches[1].rm_so], len);
 					dummy[len] = 0x00;
 					check_filter_exec((cur -> pre)[loop].cmd, dummy);
@@ -1084,7 +1094,7 @@ void do_buffer(int f_index, proginfo *cur, char *string, char filter_match, dtim
 		else
 		{
 			/* grow array */
-			lb[f_index].be = (buffered_entry *)myrealloc(lb[f_index].be, sizeof(buffered_entry) * (lb[f_index].curpos + 1), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+			lb[f_index].be = (buffered_entry *)myrealloc(lb[f_index].be, sizeof(buffered_entry) * (lb[f_index].curpos + 1));
 		}
 
 		cur_line = lb[f_index].curpos++;
@@ -1092,7 +1102,7 @@ void do_buffer(int f_index, proginfo *cur, char *string, char filter_match, dtim
 		/* add the logline itself */
 		if (string)
 		{
-			lb[f_index].be[cur_line].Bline = mystrdup(string, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+			lb[f_index].be[cur_line].Bline = mystrdup(string);
 			lb[f_index].curbytes += line_len;
 		}
 		else
@@ -1113,7 +1123,7 @@ void do_redirect(redirect_t *predir, char *buffer, int nbytes, char add_lf)
 	if (predir -> type == REDIRECTTO_SOCKET_FILTERED || predir -> type == REDIRECTTO_SOCKET)
 	{
 		int msg_len = nbytes + 6;
-		char *msg = (char *)mymalloc(msg_len + 1, __FILE__, __PRETTY_FUNCTION__, __LINE__);;
+		char *msg = (char *)mymalloc(msg_len + 1);;
 
 		snprintf(msg, msg_len, "<%d>%s\n", predir -> prio_fac, buffer);
 
@@ -1180,7 +1190,7 @@ void delete_all_markerlines(void)
 				continue;
 			}
 
-			cur_lb.be = myrealloc(cur_lb.be, (cur_lb.curpos + 1) * sizeof(buffered_entry), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+			cur_lb.be = myrealloc(cur_lb.be, (cur_lb.curpos + 1) * sizeof(buffered_entry));
 			cur_lb.be[cur_lb.curpos].Bline = (lb[index].be)[loop].Bline;
 			cur_lb.be[cur_lb.curpos].pi    = (lb[index].be)[loop].pi;
 			cur_lb.be[cur_lb.curpos].ts    = (lb[index].be)[loop].ts;
@@ -1257,7 +1267,7 @@ int emit_to_buffer_and_term(int f_index, proginfo *cur, char *line)
 		{
 			do_print_and_buffer = 1;
 			if (new_line)
-				cur -> repeat.last_line = mystrdup(new_line, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+				cur -> repeat.last_line = mystrdup(new_line);
 			else
 				cur -> repeat.last_line = NULL;
 		}
@@ -1463,7 +1473,7 @@ void create_window_set(int startx, int width, int nwindows, int indexoffset)
 	int n_lines_available = 0;
 	int n_lines_available_per_win = 0;
 	int reserved_lines = mode_statusline >= 0?1:0;
-	int *lines_per_win = (int *)mymalloc(nwindows * sizeof(int), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	int *lines_per_win = (int *)mymalloc(nwindows * sizeof(int));
 
 	set_signal(SIGWINCH, SIG_IGN, "SIGWINCH");
 
@@ -1713,8 +1723,8 @@ void create_windows(void)
 			int cols_per_col = max_x / split;
 			int win_per_col = nfd / split;
 			int x = 0, indexoffset = 0;
-			int *vs = (int *)mymalloc(sizeof(int) * split, __FILE__, __PRETTY_FUNCTION__, __LINE__);
-			int *vn = (int *)mymalloc(sizeof(int) * split, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+			int *vs = (int *)mymalloc(sizeof(int) * split);
+			int *vn = (int *)mymalloc(sizeof(int) * split);
 
 			if (vertical_split)
 			{
@@ -1806,7 +1816,7 @@ void create_windows(void)
 			{
 				n_splitlines = split - 1;
 				if (n_splitlines > 0)
-					splitlines = (NEWWIN **)mymalloc(sizeof(NEWWIN *) * n_splitlines, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+					splitlines = (NEWWIN **)mymalloc(sizeof(NEWWIN *) * n_splitlines);
 			}
 
 			for(loop=0; loop<split; loop++)
@@ -1889,10 +1899,10 @@ char close_window(int winnr, proginfo *cur)
 		int initial_n_lines_tail;
 
 		/* close old fds */
-		if (myclose(cur -> fd) == -1) error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Closing file descriptor of read-end of pipe failed.\n");
+		if (myclose(cur -> fd) == -1) error_exit("Closing file descriptor of read-end of pipe failed.\n");
 		if (cur -> fd != cur -> wfd)
 		{
-			if (myclose(cur -> wfd) == -1) error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Closing file descriptor of write-end of pipe failed.\n");
+			if (myclose(cur -> wfd) == -1) error_exit("Closing file descriptor of write-end of pipe failed.\n");
 		}
 
 		/* do diff */
@@ -1979,7 +1989,7 @@ void do_restart_window(proginfo *cur)
 
 	/* re-start tail */
 	if (start_proc(cur, 1) == -1)
-		error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Failed to start process %s.\n", cur -> filename);
+		error_exit("Failed to start process %s.\n", cur -> filename);
 }
 
 char * key_to_keybinding(char what)
@@ -2055,9 +2065,9 @@ void add_pars_per_file(char *re, char *colorscheme, int n_buffer_lines, int buff
 		n_pars_per_file++;
 
 		/* add to list */
-		ppf = (pars_per_file *)myrealloc(ppf, sizeof(pars_per_file) * n_pars_per_file, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+		ppf = (pars_per_file *)myrealloc(ppf, sizeof(pars_per_file) * n_pars_per_file);
 		memset(&ppf[loop], 0x00, sizeof(pars_per_file));
-		ppf[loop].re_str = mystrdup(re, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+		ppf[loop].re_str = mystrdup(re);
 
 		/* compile & store regular expression */
 		compile_re(&ppf[loop].regex, re);
@@ -2069,15 +2079,15 @@ void add_pars_per_file(char *re, char *colorscheme, int n_buffer_lines, int buff
 	if (colorscheme != NULL)
 	{
 		ppf[loop].n_colorschemes++;
-		ppf[loop].colorschemes = (char **)myrealloc(ppf[loop].colorschemes, sizeof(char *) * ppf[loop].n_colorschemes, __FILE__, __PRETTY_FUNCTION__, __LINE__);
-		ppf[loop].colorschemes[ppf[loop].n_colorschemes - 1] = mystrdup(colorscheme, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+		ppf[loop].colorschemes = (char **)myrealloc(ppf[loop].colorschemes, sizeof(char *) * ppf[loop].n_colorschemes);
+		ppf[loop].colorschemes[ppf[loop].n_colorschemes - 1] = mystrdup(colorscheme);
 	}
 
 	if (conversion_scheme != NULL)
 	{
 		ppf[loop].n_conversion_schemes++;
-		ppf[loop].conversion_schemes = (char **)myrealloc(ppf[loop].conversion_schemes, sizeof(char *) * ppf[loop].n_conversion_schemes, __FILE__, __PRETTY_FUNCTION__, __LINE__);
-		ppf[loop].conversion_schemes[ppf[loop].n_conversion_schemes - 1] = mystrdup(conversion_scheme, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+		ppf[loop].conversion_schemes = (char **)myrealloc(ppf[loop].conversion_schemes, sizeof(char *) * ppf[loop].n_conversion_schemes);
+		ppf[loop].conversion_schemes[ppf[loop].n_conversion_schemes - 1] = mystrdup(conversion_scheme);
 	}
 
 	if (n_buffer_lines != -1)
@@ -2149,7 +2159,7 @@ void set_default_parameters_if_not_given_do(proginfo *cur, int pi_index)
 {
 	int maxnlines = default_maxnlines, maxbytes = default_maxbytes;
 	int pm = find_path_max();
-	char *real_fname = (char *)mymalloc(pm, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	char *real_fname = (char *)mymalloc(pm);
 
 	do
 	{
@@ -2163,7 +2173,7 @@ void set_default_parameters_if_not_given_do(proginfo *cur, int pi_index)
 		else
 		{
 			if (!realpath(cur -> filename, real_fname))
-				error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Problem obtaining complete (real) path of file %s.\n", cur -> filename);
+				error_exit("Problem obtaining complete (real) path of file %s.\n", cur -> filename);
 		}
 
 		/* check if any default parameters are given in the configfile */
@@ -2197,7 +2207,7 @@ void set_default_parameters_if_not_given_do(proginfo *cur, int pi_index)
 					{
 						int cs_index = find_colorscheme(ppf[ppf_index].colorschemes[c_nr]);
 						if (cs_index == -1)
-							error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Color scheme '%s' is not known.\n", ppf[ppf_index].colorschemes[c_nr]);
+							error_exit("Color scheme '%s' is not known.\n", ppf[ppf_index].colorschemes[c_nr]);
 						add_color_scheme(&cur -> cdef.color_schemes, cs_index);
 					}
 					cur -> cdef.colorize = 'S';
@@ -2281,11 +2291,11 @@ void start_all_processes(char *nsubwindows)
 			{
 				int old_0 = mydup(0);
 
-				if (old_0 == -1) error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Cannot dup(0).\n");
+				if (old_0 == -1) error_exit("Cannot dup(0).\n");
 
-				if (myclose(0) == -1) error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Error closing fd 0.\n");
+				if (myclose(0) == -1) error_exit("Error closing fd 0.\n");
 
-				if (myopen("/dev/tty", O_RDONLY) != 0) error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "New fd != 0\n");
+				if (myopen("/dev/tty", O_RDONLY) != 0) error_exit("New fd != 0\n");
 
 				cur -> fd = old_0;
 				cur -> wfd = -1;
@@ -2293,35 +2303,58 @@ void start_all_processes(char *nsubwindows)
 			}
 			else if (cur -> wt == WT_SOCKET)
 			{
-				char *dummy = mystrdup(cur -> filename, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+				char *dummy = mystrdup(cur -> filename);
 				char *colon = strchr(dummy, ':');
-				struct sockaddr_in sa;
-				socklen_t ssai_len = sizeof(sa);
-				char *host = "0.0.0.0";
-				int port = 514;
+				struct addrinfo hints;
+				struct addrinfo* result;
+				struct addrinfo* rp;
+				int sfd = -1, s;
 
-				cur -> wfd = cur -> fd = socket(AF_INET, SOCK_DGRAM, 0);
-				if (cur -> fd == -1)
-					error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Failed to create socket for receiving syslog data.\n");
+				char *host = NULL;
+				char *service = "syslog";
 
 				if (colon)
 				{
-					port = atoi(colon + 1);
-					if (port <= 0)
-						error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "--[Ll]isten requires a >= 0 portnumber.\n");
+					service = colon + 1;
 					*colon = 0x00;
 					if (colon > dummy)
 						host = dummy;
 				}
 
-				memset(&sa, 0x00, ssai_len);
-				sa.sin_family = AF_INET;
-				sa.sin_port   = htons(port);
-				sa.sin_addr.s_addr = inet_addr(host);
-				if (bind(cur -> fd, (struct sockaddr *)&sa, ssai_len) == -1)
-					error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Failed to bind socket to %s.\n", cur -> filename);
+				memset(&hints, 0x00, sizeof(struct addrinfo));
+				hints.ai_family = AF_UNSPEC;
+				hints.ai_socktype = SOCK_DGRAM;
+				hints.ai_flags = AI_PASSIVE;
+				hints.ai_protocol = 0;
+				hints.ai_canonname = NULL;
+				hints.ai_addr = NULL;
+				hints.ai_next = NULL;
 
-				myfree(dummy);
+				s = getaddrinfo(host, service, &hints, &result);
+				if (s != 0)
+					error_exit("Failed to create socket for receiving syslog data on %s: %s.\n", cur -> filename, gai_strerror(s));
+
+				for (rp = result; rp != NULL; rp = rp -> ai_next)
+				{
+					sfd = socket(rp -> ai_family, rp -> ai_socktype, rp -> ai_protocol);
+					if (sfd == -1)
+						continue;
+					if (bind(sfd, rp -> ai_addr, rp -> ai_addrlen) == 0)
+						break;
+					close(sfd);
+				}
+
+				freeaddrinfo(result);
+
+				if (rp == NULL)
+					error_exit("Failed to create socket for receiving syslog data on %s.\n", cur -> filename);
+
+				cur -> wfd = cur -> fd = sfd;
+
+				cur -> wfd = cur -> fd = socket(AF_INET, SOCK_DGRAM, 0);
+				if (cur -> fd == -1)
+
+					myfree(dummy);
 
 				cur -> pid = -1;
 			}
@@ -2332,7 +2365,7 @@ void start_all_processes(char *nsubwindows)
 
 				/* start the tail process for this file/command */
 				if (start_proc(cur, cur -> initial_n_lines_tail) == -1)
-					error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Failed to start process for %s.\n", cur -> filename);
+					error_exit("Failed to start process for %s.\n", cur -> filename);
 			}
 
 			cur = cur -> next;
@@ -2376,7 +2409,7 @@ void init_check_for_mail(void)
 void main_loop(void)
 {
 	/* create windows */
-	do_refresh = 2;
+	set_do_refresh(2);
 
 	for(;;)
 	{
@@ -2386,7 +2419,7 @@ void main_loop(void)
 		{
 			int uc = toupper(c);
 
-			do_refresh = 1;
+			set_do_refresh(1);
 
 			if (mail)
 			{
@@ -2396,7 +2429,7 @@ void main_loop(void)
 
 			if (c == -1)
 			{
-				do_refresh = 2;
+				set_do_refresh(2);
 				continue;
 			}
 			else if (uc == 'Q' || uc == 'X')
@@ -2406,13 +2439,13 @@ void main_loop(void)
 			else if (c == 'Z')	/* clear all marker lines */
 			{
 				delete_all_markerlines();
-				do_refresh = 2;
+				set_do_refresh(2);
 				continue;
 			}
 			else if (uc == 'A')
 			{
 				if (add_window())
-					do_refresh = 2;
+					set_do_refresh(2);
 				continue;
 			}
 			else if (uc == 'H' || c == 8)
@@ -2422,7 +2455,7 @@ void main_loop(void)
 			}
 			else if (c == 'r' || c == 12)
 			{
-				do_refresh = 2;
+				set_do_refresh(2);
 				continue;
 			}
 			else if (c == 'R')
@@ -2448,7 +2481,7 @@ void main_loop(void)
 			else if (uc == 'J')
 			{
 				if (set_window_sizes())
-					do_refresh = 2;
+					set_do_refresh(2);
 				continue;
 			}
 			else if (uc == 'L')
@@ -2460,35 +2493,35 @@ void main_loop(void)
 			if (nfd == 0)
 			{
 				wrong_key();
-				do_refresh = 0;
+				set_do_refresh(0);
 				continue;
 			}
 
 			else if (uc == 'E' || uc == '\\')
 			{
 				if (edit_regexp())
-					do_refresh = 2;
+					set_do_refresh(2);
 			}
 			else if (uc == 'F')
 			{
 				if (edit_strippers())
-					do_refresh = 2;
+					set_do_refresh(2);
 			}
 			else if (uc == 'D')
 			{
 				if (delete_window())
-					do_refresh = 2;
+					set_do_refresh(2);
 				continue;
 			}
 			else if (uc == 'V')
 			{
 				if (toggle_vertical_split())
-					do_refresh = 2;
+					set_do_refresh(2);
 			}
 			else if (c == 'c')
 			{
 				if (toggle_colors())
-					do_refresh = 2;
+					set_do_refresh(2);
 			}
 			else if (c == 'C' && use_colors)
 			{
@@ -2500,23 +2533,23 @@ void main_loop(void)
 			else if (uc == 'S')
 			{
 				if (swap_window())
-					do_refresh = 2;
+					set_do_refresh(2);
 				continue;
 			}
 			else if (c == 'z')
 			{
 				if (hide_window())
-					do_refresh = 2;
+					set_do_refresh(2);
 			}
 			else if (c == 'u')
 			{
 				if (hide_all_but())
-					do_refresh = 2;
+					set_do_refresh(2);
 			}
 			else if (c == 'U')
 			{
 				if (unhide_all_windows())
-					do_refresh = 2;
+					set_do_refresh(2);
 			}
 			else if (uc == 'G')
 			{
@@ -2585,7 +2618,7 @@ void main_loop(void)
 			else if (c == 'y')	/* set linewrap */
 			{
 				set_linewrap();
-				do_refresh = 2;
+				set_do_refresh(2);
 			}
 			else if (c == 'Y')	/* send a signal to a window */
 			{
@@ -2598,7 +2631,7 @@ void main_loop(void)
 			else if (c == '?')	/* highlight in all windows */
 			{
 				highlight_in_all_windows();
-				do_refresh = 2;
+				set_do_refresh(2);
 			}
 			else if (c == 'I')
 			{
@@ -2607,7 +2640,7 @@ void main_loop(void)
 			else if (c == 20)	/* ^t */
 			{
 				toggle_subwindow_nr();
-				do_refresh = 2;
+				set_do_refresh(2);
 			}
 			else if (c == 22)	/* ^v */
 			{
@@ -2624,18 +2657,16 @@ void main_loop(void)
 			else if (c == KEY_LEFT || c == KEY_RIGHT)
 			{
 				horizontal_scroll(c);
-				do_refresh = 2;
+				set_do_refresh(2);
 			}
 			else
 			{
 				if (exec_bind(c))
-				{
-					do_refresh = 1;
-				}
+					set_do_refresh(1);
 				else
 				{
 					wrong_key();
-					do_refresh = 0;
+					set_do_refresh(0);
 				}
 			}
 		}
@@ -2651,9 +2682,9 @@ void check_for_valid_stdin()
 	if (!ttyname(0))
 	{
 		if (errno == ENOTTY || errno == EINVAL)
-			error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Please use -j/-J when you want to pipe something into MultiTail.\n");
+			error_exit("Please use -j/-J when you want to pipe something into MultiTail.\n");
 		else
-			error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "ttyname(0) failed.\n");
+			error_exit("ttyname(0) failed.\n");
 	}
 }
 
@@ -2680,15 +2711,15 @@ int main(int argc, char *argv[])
 	set_signal(SIGHUP,  signal_handler, "SIGHUP" );
 	set_signal(SIGCHLD, signal_handler, "SIGCHLD");
 
-	shell            = mystrdup("/bin/sh", __FILE__, __PRETTY_FUNCTION__, __LINE__);
-	tail             = mystrdup("tail", __FILE__, __PRETTY_FUNCTION__, __LINE__);
-	ts_format        = mystrdup("%b %d %H:%M:%S", __FILE__, __PRETTY_FUNCTION__, __LINE__);
-	window_number    = mystrdup("[%02d]", __FILE__, __PRETTY_FUNCTION__, __LINE__);
-	cnv_ts_format    = mystrdup("%b %d %H:%M:%S %Y", __FILE__, __PRETTY_FUNCTION__, __LINE__);
-	line_ts_format   = mystrdup("%b %d %H:%M:%S %Y ", __FILE__, __PRETTY_FUNCTION__, __LINE__);
-	subwindow_number = mystrdup("[%02d]", __FILE__, __PRETTY_FUNCTION__, __LINE__);
-	statusline_ts_format = mystrdup("%b %d %H:%M:%S %Y", __FILE__, __PRETTY_FUNCTION__, __LINE__);
-	syslog_ts_format = mystrdup("%b %d %H:%M:%S %Y", __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	shell            = mystrdup("/bin/sh");
+	tail             = mystrdup("tail");
+	ts_format        = mystrdup("%b %d %H:%M:%S");
+	window_number    = mystrdup("[%02d]");
+	cnv_ts_format    = mystrdup("%b %d %H:%M:%S %Y");
+	line_ts_format   = mystrdup("%b %d %H:%M:%S %Y ");
+	subwindow_number = mystrdup("[%02d]");
+	statusline_ts_format = mystrdup("%b %d %H:%M:%S %Y");
+	syslog_ts_format = mystrdup("%b %d %H:%M:%S %Y");
 
 	mail_spool_file = getenv("MAIL");
 	if (dummy) check_for_mail = atoi(dummy);
@@ -2707,6 +2738,9 @@ int main(int argc, char *argv[])
 
 	init_colornames();
 
+	/* start curses library */
+	init_ncurses();
+
 	/* verify size of terminal window */
 	if (LINES < 23 || COLS < 78)
 		error_popup("Terminal too small", -1, "Your terminal(-window) is %dx%d. That is too small\nfor MultiTail: at least 78x23 is required.\nSome menus will look garbled!", COLS, LINES);
@@ -2731,7 +2765,7 @@ int main(int argc, char *argv[])
 		default_color_scheme = find_colorscheme(defaultcscheme);
 
 		if (default_color_scheme == -1)
-			error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Default color scheme '%s' is not defined. Please check the MultiTail configuration file %s.\n", defaultcscheme, config_file);
+			error_exit("Default color scheme '%s' is not defined. Please check the MultiTail configuration file %s.\n", defaultcscheme, config_file);
 	}
 
 	if (markerline_attrs.colorpair_index == -1 && markerline_attrs.attrs == -1)
@@ -2742,9 +2776,6 @@ int main(int argc, char *argv[])
 	/* initialise mail-stuff */
 	init_check_for_mail();
 
-	/* start curses library */
-	init_ncurses();
-
 	/* it seems that on at least FreeBSD ncurses forgets all defined
 	 * colorpairs after an endwin()
 	 * so here were explicitly re-setting them
@@ -2789,14 +2820,14 @@ void sigusr1_restart_tails(void)
 
 				stop_process(cur -> pid);
 
-				if (myclose(cur -> fd) == -1) error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Closing read filedescriptor failed.\n");
+				if (myclose(cur -> fd) == -1) error_exit("Closing read filedescriptor failed.\n");
 				if (cur -> fd != cur -> wfd)
 				{
-					if (myclose(cur -> wfd) == -1) error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Closing write filedescriptor failed.\n");
+					if (myclose(cur -> wfd) == -1) error_exit("Closing write filedescriptor failed.\n");
 				}
 
 				/* create a pipe, will be to child-process */
-				if (-1 == pipe(pipefd)) error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Error while creating pipe.\n");
+				if (-1 == pipe(pipefd)) error_exit("Error while creating pipe.\n");
 
 				cur -> pid = start_tail(cur -> filename, cur -> retry_open, cur -> follow_filename, min_n_bufferlines, pipefd);
 				cur -> fd = pipefd[0];
@@ -2830,7 +2861,7 @@ int check_for_died_processes(void)
 			if (errno == ECHILD)
 				break;
 
-			error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "waitpid failed.\n");
+			error_exit("waitpid failed.\n");
 		}
 
 		/* now check every window for died processes */
@@ -2850,11 +2881,12 @@ int check_for_died_processes(void)
 					/* is an entry deleted? (>=0) or restarted? (==-1) */
 					if (refresh_info >= 0)
 					{
-						do_refresh = 2;
+						set_do_refresh(2);
 					}
-					else if (cur -> restart.do_diff && do_refresh == 0)
+					else if (cur -> restart.do_diff && get_do_refresh() == 0)
 					{
-						if (do_refresh != 2) do_refresh = 1;
+						if (get_do_refresh() != 2)
+							set_do_refresh(1);
 					}
 
 					break;
@@ -2919,8 +2951,8 @@ void create_new_win(proginfo **cur, int *nr)
 {
 	int loop;
 
-	proginfo *newpi = (proginfo *)myrealloc(pi, (nfd + 1) * sizeof(proginfo), __FILE__, __PRETTY_FUNCTION__, __LINE__);
-	lb = (buffer *)myrealloc(lb, (nfd + 1) * sizeof(buffer), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	proginfo *newpi = (proginfo *)myrealloc(pi, (nfd + 1) * sizeof(proginfo));
+	lb = (buffer *)myrealloc(lb, (nfd + 1) * sizeof(buffer));
 
 	/* 'lb' has pointers to 'pi'-structures. now since we've realloced the pi-
 	 * array, we need to update to pointers to pi in the lb-array
@@ -2951,7 +2983,7 @@ int check_paths(void)
 
 	for(loop=0; loop<n_cdg; loop++)
 	{
-		if ((now - cdg[loop].last_check) >= cdg[loop].check_interval)
+		if (now - cdg[loop].last_check >= cdg[loop].check_interval)
 		{
 			int fi;
 			glob_t files;
@@ -2999,13 +3031,13 @@ int check_paths(void)
 						while (cur -> next) cur = cur -> next;
 
 						/* allocate new entry */
-						cur -> next = (proginfo *)mymalloc(sizeof(proginfo), __FILE__, __PRETTY_FUNCTION__, __LINE__);
+						cur -> next = (proginfo *)mymalloc(sizeof(proginfo));
 						cur = cur -> next;
 						memset(cur, 0x00, sizeof(proginfo));
 					}
 
 					/* fill in */
-					cur -> filename = mystrdup(files.gl_pathv[fi], __FILE__, __PRETTY_FUNCTION__, __LINE__);
+					cur -> filename = mystrdup(files.gl_pathv[fi]);
 					cur -> line_wrap = default_linewrap;
 					cur -> win_height = -1;
 					cur -> statistics.sccfirst = 1;
@@ -3013,7 +3045,7 @@ int check_paths(void)
 
 					/* start the tail process for this file/command */
 					if (start_proc(cur, max_y / nfd) == -1)
-						error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Failed to start tail process for %s.\n", cur -> filename);
+						error_exit("Failed to start tail process for %s.\n", cur -> filename);
 
 					new_wins = 1;
 				}
@@ -3030,7 +3062,7 @@ void resize_terminal_do(NEWWIN *popup)
 {
 	determine_terminal_size(&max_y, &max_x);
 
-	if (ERR == resizeterm(max_y, max_x)) error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "An error occured while resizing terminal(-window).\n");
+	if (ERR == resizeterm(max_y, max_x)) error_exit("An error occured while resizing terminal(-window).\n");
 
 	endwin();
 	refresh(); /* <- as specified by ncurses faq, was: doupdate(); */
@@ -3053,21 +3085,24 @@ void resize_terminal_do(NEWWIN *popup)
 
 int process_global_keys(int what_help, NEWWIN *popup, char cursor_shift)
 {
-	int c;
+	int c = getch();
 
-	c = getch();
+	if (c == KEY_RESIZE)
+		return -1;
 
 	redraw_statuslines();
 
-	if (c == KEY_RESIZE || c == KEY_F(5))
+	if (c == KEY_F(5))
 	{
 		resize_terminal_do(popup);
-		do_refresh = 2;
+
+		set_do_refresh(2);
 	}
 	else if (c == exit_key)     /* ^C */
 	{
 		do_exit();
-		error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "This should not be reached.\n");
+
+		error_exit("This should not be reached.\n");
 	}
 	else if (c == 8 || c == KEY_F(1))       /* HELP (^h / F1) */
 	{
@@ -3117,12 +3152,8 @@ int process_global_keys(int what_help, NEWWIN *popup, char cursor_shift)
 		else
 			wrong_key();
 	}
-	else
-	{
-		return c;
-	}
 
-	return -1;
+	return c;
 }
 
 char process_input_data(int win_nr, proginfo *cur, char *data_in, int new_data_offset, int n_bytes_added, double now)
@@ -3193,8 +3224,8 @@ char process_input_data(int win_nr, proginfo *cur, char *data_in, int new_data_o
 			}
 			else /* no, just output */
 			{
-				if (do_refresh == 0)
-					do_refresh = 1;	/* after update interval, update screen */
+				if (get_do_refresh() == 0)
+					set_do_refresh(1); /* after update interval, update screen */
 
 				statusline_update_needed |= emit_to_buffer_and_term(win_nr, cur, pnt);
 			}
@@ -3219,7 +3250,7 @@ char process_input_data(int win_nr, proginfo *cur, char *data_in, int new_data_o
 	if (*pnt != 0x00)
 	{
 		int line_len = strlen(pnt) + 1;
-		cur -> incomplete_line = mymalloc(line_len, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+		cur -> incomplete_line = mymalloc(line_len);
 		memcpy(cur -> incomplete_line, pnt, line_len);
 	}
 
@@ -3230,7 +3261,7 @@ int recv_from_fd(int fd, char **buffer, int new_data_offset, int read_size)
 {
 	struct sockaddr sa;
 	socklen_t ssa_len = sizeof(sa);
-	char *recv_buffer = mymalloc(read_size + 1,  __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	char *recv_buffer = mymalloc(read_size + 1);
 	char time_buffer[TIMESTAMP_EXTEND_BUFFER];
 	int time_len;
 	char *host = "";
@@ -3282,7 +3313,7 @@ int recv_from_fd(int fd, char **buffer, int new_data_offset, int read_size)
 
 	added_bytes = strlen(time_buffer) + 1 + strlen(host) + 1 + strlen(facility) + 1 + strlen(severity) + 1 + 1 + nbytes + 1;
 
-	*buffer = myrealloc(*buffer, new_data_offset + added_bytes, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+	*buffer = myrealloc(*buffer, new_data_offset + added_bytes);
 
 	nbytes = snprintf(&(*buffer)[new_data_offset], added_bytes, "%s%s%s%s%s%s%s%s %s\n",
 			time_buffer, time_buffer[0]?" ":"",
@@ -3313,22 +3344,14 @@ int wait_for_keypress(int what_help, double max_wait, NEWWIN *popup, char cursor
 		static double lastupdate = 0;
 		double sleep = 32767.0;
 
-		if (heartbeat_interval > 0 && (get_ts() - heartbeat_t) >= heartbeat_interval)
-		{
-			heartbeat();
-			heartbeat_t = get_ts();
-		}
-
 		/* need to check any paths? */
 		if (check_paths())
-			do_refresh = 2;
-
-		/* check for mail */
-		do_check_for_mail(now);
+			set_do_refresh(2);
 
 		sleep = min(sleep, check_for_mail > 0     ? max((msf_last_check + check_for_mail)  - now, 0) : 32767);
 		sleep = min(sleep, heartbeat_interval > 0 ? max((heartbeat_t + heartbeat_interval) - now, 0) : 32767);
 		sleep = min(sleep, max_wait > 0.0         ? max((max_wait_start + max_wait)        - now, 0) : 32767);
+
 		for(loop=0; loop<n_cdg; loop++)
 			sleep = min(sleep, max((cdg[loop].last_check + cdg[loop].check_interval) - now, 0));
 
@@ -3376,14 +3399,14 @@ int wait_for_keypress(int what_help, double max_wait, NEWWIN *popup, char cursor
 		}
 
 		/* update screen? */
-		if (do_refresh)
+		if (get_do_refresh())
 		{
-			if (do_refresh == 2)
+			if (get_do_refresh() == 2)
 				create_windows();
 
-			if ((now - lastupdate) >= update_interval)
+			if (now - lastupdate >= update_interval)
 			{
-				do_refresh = 0;
+				set_do_refresh(0);
 				lastupdate = now;
 				mydoupdate();
 			}
@@ -3393,11 +3416,26 @@ int wait_for_keypress(int what_help, double max_wait, NEWWIN *popup, char cursor
 		if ((rc = select(last_fd + 1, &rfds, NULL, NULL, tv.tv_sec != 32767 ? &tv : NULL)) == -1)
 		{
 			if (errno != EINTR && errno != EAGAIN)
-				error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "select() returned an error.");
+				error_exit("select() returned an error.");
 		}
 
 		now = get_ts();
 
+		if (heartbeat_interval > 0 && now - heartbeat_t >= heartbeat_interval)
+		{
+			heartbeat();
+
+			heartbeat_t = now;
+		}
+
+		/* check for mail */
+		if (now - msf_last_check >= check_for_mail)
+		{
+			do_check_for_mail(now);
+
+			msf_last_check = now;
+		}
+
 		total_wakeups++;
 
 		if (terminal_changed)
@@ -3406,7 +3444,7 @@ int wait_for_keypress(int what_help, double max_wait, NEWWIN *popup, char cursor
 			resize_terminal_do(popup);
 		}
 
-		if (max_wait != 0.0 && (get_ts() - max_wait_start) >= max_wait)
+		if (max_wait != 0.0 && now - max_wait_start >= max_wait)
 			break;
 
 		if (got_sigusr1)
@@ -3425,9 +3463,7 @@ int wait_for_keypress(int what_help, double max_wait, NEWWIN *popup, char cursor
 
 				c = process_global_keys(what_help, popup, cursor_shift);
 				if (c != -1)
-				{
 					break;
-				}
 			}
 
 			/* go through all fds */
@@ -3451,7 +3487,7 @@ int wait_for_keypress(int what_help, double max_wait, NEWWIN *popup, char cursor
 						int read_size = min(SSIZE_MAX, 65536);
 						int nbytes, new_data_offset = cur -> incomplete_line ? strlen(cur -> incomplete_line) : 0;
 
-						buffer = myrealloc(cur -> incomplete_line, new_data_offset + read_size + 1, __FILE__, __PRETTY_FUNCTION__, __LINE__);
+						buffer = myrealloc(cur -> incomplete_line, new_data_offset + read_size + 1);
 						cur -> incomplete_line = NULL;
 
 						if (cur -> wt == WT_SOCKET)
@@ -3470,21 +3506,24 @@ int wait_for_keypress(int what_help, double max_wait, NEWWIN *popup, char cursor
 							{
 								pi[loop].paused = 1;
 								update_statusline(status, loop, cur);
-								do_refresh = 2;
+								set_do_refresh(2);
 							}
 							else
 							{
-								if (last_changed_window == cur) last_changed_window = NULL;
+								if (last_changed_window == cur)
+									last_changed_window = NULL;
+
 								deleted_entry_in_array = close_window(loop, cur);
 
 								if (deleted_entry_in_array >= 0)
 								{
-									do_refresh = 2;
+									set_do_refresh(2);
 									goto closed_window;
 								}
-								else if (cur -> restart.do_diff && do_refresh == 0)
+								else if (cur -> restart.do_diff && get_do_refresh() == 0)
 								{
-									if (do_refresh != 2) do_refresh = 1;
+									if (get_do_refresh() != 2)
+										set_do_refresh(1);
 								}
 							}
 						}
@@ -3506,26 +3545,30 @@ int wait_for_keypress(int what_help, double max_wait, NEWWIN *popup, char cursor
 					}
 
 					/* close idle, if requested */
-					if (cur -> close_idle > 0 && (time(NULL) - cur -> statistics.lastevent) > cur -> close_idle)
+					if (cur -> close_idle > 0 && now - cur -> statistics.lastevent > cur -> close_idle)
 					{
-						if (last_changed_window == cur) last_changed_window = NULL;
+						if (last_changed_window == cur)
+							last_changed_window = NULL;
+
 						deleted_entry_in_array = close_window(loop, cur);
 						if (deleted_entry_in_array >= 0)
 						{
-							do_refresh = 2;
+							set_do_refresh(2);
+
 							goto closed_window;
 						}
 					}
 
 					if (cur -> mark_interval)
 					{
-						if ((time(NULL) - cur -> statistics.lastevent) >= cur -> mark_interval)
+						if (now - cur -> statistics.lastevent >= cur -> mark_interval)
 						{
 							add_markerline(loop, cur, MARKER_IDLE, NULL);
 
-							if (do_refresh == 0) do_refresh = 1;
+							if (get_do_refresh() == 0)
+								set_do_refresh(1);
 
-							cur -> statistics.lastevent = time(NULL);
+							cur -> statistics.lastevent = now;
 						}
 					}
 
